rm(list = ls())
set.seed(1)
source("custom11-uniquedelta.R")
Rcpp::sourceCpp('loopC-general.cpp')

#############Libraries###################
  library("ape")
  library("numDeriv")
  library("Rcpp")
  library("markophylo")
#########################################

tree2 <- ape::read.tree("dropped-fourfold.tre")
dsim <- read.table("ABCD_subgenomeIDed-LS.txt",header = T)
thr <- 3 #3 because 3 or more zeros is not allowed.

#Order data by tip labels of tree
dsims <- t(dsim)[,tree2$tip.label]
dsims[dsims == "A"] <- "a" #small "a" hardcoded into model code...
apply(X = dsims, MARGIN = 2, FUN = table)
laev_tip <- which(tree2$tip.label == "laevis")

########generating unobservable patterns##########
alphabet <- c("a", "L", "S", "D") #a is (0,0); L is (0,1); S is (1,0); D is (1,1)
allpat1 <- expand.grid(alphabet, alphabet, alphabet, alphabet, alphabet) #creat all combinations of factors
allpat <- as.matrix(allpat1)
correctfor_max2 <- allpat[sort(union(which(!apply(allpat, MARGIN = 1, FUN = function(x) any(x == "D")) ) , which(apply(allpat, MARGIN = 1, FUN = function(x) table(x)["a"] >= thr)) )), ]#which rows do not contain a "d" and #which rows contain "thr" or more "a"s
gg_max2 <- which(apply(correctfor_max2, MARGIN = 1, FUN = function(x) x[laev_tip] == "a") )
correctformax2 <- correctfor_max2[-gg_max2, ]

toi <- (1:5)[-laev_tip] #missing data proportion fitted for any taxa that is not laevis.

###############################

bglist3 <- list(c(6,7),c(6,8),c(7,1,2),c(8,9,3,4,5))
bglist4 <- list(c(6,7,1,2),c(6,8,9,3,4,5))

model_homo_2clades <- pseudorates(usertree = tree2, userphyl = dsims, matchtipstodata = TRUE, alphabet = c("L","S","D"), unobserved = correctformax2, toi = toi, bgtype = "listofnodes", bg = bglist4, rootprob = "user", rpvec = c(0,0,1), lowli = 0.0001, upli = 100, numhessian = TRUE, modelmat = matrix(c(NA,0,1,0,NA,1,0,0,NA),3,3) )
print(model_homo_2clades)

model_subgenome_2clades <- pseudorates(usertree = tree2, userphyl = dsims, matchtipstodata = TRUE, alphabet = c("L","S","D"), unobserved = correctformax2, toi = toi, bgtype = "listofnodes", bg = bglist4, rootprob = "user", rpvec = c(0,0,1), lowli = 0.0001, upli = 100, numhessian = TRUE, modelmat = matrix(c(NA,0,1,0,NA,2,0,0,NA),3,3) )
print(model_subgenome_2clades)

model_time_2clades <- pseudorates(usertree = tree2, userphyl = dsims, matchtipstodata = TRUE, alphabet = c("L","S","D"), unobserved = correctformax2, toi = toi, bgtype = "listofnodes", bg = bglist3, rootprob = "user", rpvec = c(0,0,1), lowli = 0.0001, upli = 100, numhessian = TRUE, modelmat = matrix(c(NA,0,1,0,NA,1,0,0,NA),3,3) )
print(model_time_2clades)

model_timehetero_linehetero_2clades <- pseudorates(usertree = tree2, userphyl = dsims, matchtipstodata = TRUE, alphabet = c("L","S","D"), unobserved = correctformax2, toi = toi, bgtype = "listofnodes", bg = bglist3, rootprob = "user", rpvec = c(0,0,1), lowli = 0.0001, upli = 100, numhessian = TRUE, modelmat = matrix(c(NA,0,1,0,NA,2,0,0,NA),3,3) )
print(model_timehetero_linehetero_2clades)
